% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findSCEs.R
\name{getSCEcoordinates}
\alias{getSCEcoordinates}
\title{Get SCE coordinates}
\usage{
getSCEcoordinates(model, resolution = c(3, 6), min.segwidth = 2,
  fragments = NULL)
}
\arguments{
\item{model}{An \code{\link{aneuBiHMM}} object.}

\item{resolution}{An integer vector specifying the resolution at bin level at which to scan for SCE events.}

\item{min.segwidth}{Segments below this width will be removed before scanning for SCE events.}

\item{fragments}{A \code{\link{GRanges-class}} object with read fragments or a file that contains such an object. These reads will be used for fine mapping of the SCE events.}
}
\value{
A \code{\link{GRanges-class}} object containing the SCE coordinates.
}
\description{
Extracts the coordinates of a sister chromatid exchanges (SCE) from an \code{\link{aneuBiHMM}} object.
}
\examples{
## Get an example BED file with single-cell-sequencing reads
bedfile <- system.file("extdata", "KK150311_VI_07.bam.bed.gz", package="AneuFinderData")
## Bin the BAM file into bin size 1Mp
binned <- binReads(bedfile, assembly='hg19', binsize=1e6,
                  chromosomes=c(1:22,'X','Y'), pairedEndReads=TRUE)
## Fit the Hidden Markov Model
## Find copy-numbers
model <- findCNVs.strandseq(binned[[1]])
## Find sister chromatid exchanges
model$sce <- getSCEcoordinates(model)
print(model$sce)
plot(model)

}
\author{
Aaron Taudt
}
