% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotting.R
\name{plot_pca}
\alias{plot_pca}
\title{Perform a PCA for copy number profiles}
\usage{
plot_pca(hmms, PC1 = 1, PC2 = 2, colorBy = NULL, plot = TRUE,
  exclude.regions = NULL)
}
\arguments{
\item{hmms}{A list of \code{\link{aneuHMM}} objects or a character vector with files that contain such objects.}

\item{PC1}{Integer specifying the first of the principal components to plot.}

\item{PC2}{Integer specifying the second of the principal components to plot.}

\item{colorBy}{A character vector of the same length as \code{hmms} which is used to color the points in the plot.}

\item{plot}{Set to \code{FALSE} if you want to return the data.frame that is used for plotting instead of the plot.}

\item{exclude.regions}{A \code{\link{GRanges-class}} with regions that will be excluded from the computation of the PCA. This can be useful to exclude regions with artifacts.}
}
\value{
A \code{\link[ggplot2:ggplot]{ggplot}} object or a data.frame if \code{plot=FALSE}.
}
\description{
Perform a PCA for copy number profiles in \code{\link{aneuHMM}} objects.
}
\examples{
## Get results from a small-cell-lung-cancer
lung.folder <- system.file("extdata", "primary-lung", "hmms", package="AneuFinderData")
lung.files <- list.files(lung.folder, full.names=TRUE)
## Get results from the liver metastasis of the same patient
liver.folder <- system.file("extdata", "metastasis-liver", "hmms", package="AneuFinderData")
liver.files <- list.files(liver.folder, full.names=TRUE)
## Plot the PCA
classes <- c(rep('lung', length(lung.files)), rep('liver', length(liver.files)))
labels <- c(paste('lung',1:length(lung.files)), paste('liver',1:length(liver.files)))
plot_pca(c(lung.files, liver.files), colorBy=classes, PC1=2, PC2=4)

}
